@@ -767,11 +767,10 @@ Xen eval_str_wrapper(void *data)
 
 static Xen eval_file_wrapper(void *data)
 {
-  Xen error;
   last_file_loaded = (char *)data;
-  error = Xen_load((char *)data); /* error only meaningful in Ruby */
+  Xen_load((char *)data);
   last_file_loaded = NULL;
-  return(error);
+  return(Xen_true);
 }
 
 
@@ -1486,7 +1485,7 @@ mus_long_t string_to_mus_long_t(const char *str, mus_long_t lo, const char *fiel
       mus_long_t val;
       val = Xen_llong_to_C_llong(res);
       if (val < lo)
-	snd_error("%s: %lld is invalid", field_name, val);
+	snd_error("%s: %" PRId64 " is invalid", field_name, val);
       else return(val);
     }
   else snd_error("%s: %s is not a number", field_name, str);
@@ -1495,12 +1494,12 @@ mus_long_t string_to_mus_long_t(const char *str, mus_long_t lo, const char *fiel
   mus_long_t res = 0;
   if (str) 
     {
-      if (!(sscanf(str, "%lld" , &res)))
+      if (!(sscanf(str, "%" PRId64, &res)))
 	snd_error("%s: %s is not a number", field_name, str);
       else
 	{
 	  if (res < lo)
-	    snd_error("%s: %lld is invalid", field_name, res);
+	    snd_error("%s: %" PRId64 " is invalid", field_name, res);
 	}
     }
   return(res);
@@ -2968,7 +2967,7 @@ be written, or rely on the default (-1.0 or 1.0 depending on the sign of 'val').
   } 
 
 #if HAVE_SCHEME
-  Xen_define_typed_procedure("_snd_s7_error_handler_", g_snd_s7_error_handler_w,  0, 1, 0, "internal error redirection for snd/s7",
+  Xen_define_typed_procedure("_snd_s7_error_handler_", g_snd_s7_error_handler_w,  1, 0, 0, "internal error redirection for snd/s7",
 			     s7_make_signature(s7, 2, b, s));
 
   Xen_eval_C_string("(define redo-edit redo)");        /* consistency with Ruby */
@@ -2999,7 +2998,7 @@ be written, or rely on the default (-1.0 or 1.0 depending on the sign of 'val').
                  (format ap-port \"~%~A: ~A\"   \
 		         (car binding)   \
 		         (if (procedure? (cdr binding))  \
-		             (procedure-documentation (cdr binding))  \
+		             (documentation (cdr binding))  \
 		             (cdr binding))))))  \
          ap-env) \
          #f))");
